@@ -79,10 +79,10 @@ FlatpakBackend::FlatpakBackend(QObject* parent)
     , m_updater(new StandardBackendUpdater(this))
     , m_reviews(AppStreamIntegration::global()->reviews())
     , m_refreshAppstreamMetadataJobs(0)
+    , m_cancellable(g_cancellable_new())
     , m_threadPool(new QThreadPool(this))
 {
     g_autoptr(GError) error = nullptr;
-    m_cancellable = g_cancellable_new();
 
     connect(m_updater, &StandardBackendUpdater::updatesCountChanged, this, &FlatpakBackend::updatesCountChanged);
 
