@@ -40,6 +40,7 @@ FwupdBackend::FwupdBackend(QObject* parent)
     : AbstractResourcesBackend(parent)
     , client(fwupd_client_new())
     , m_updater(new StandardBackendUpdater(this))
+    , m_cancellable(g_cancellable_new())
 {
     connect(m_updater, &StandardBackendUpdater::updatesCountChanged, this, &FwupdBackend::updatesCountChanged);
 
@@ -61,6 +62,11 @@ QMap<GChecksumType, QCryptographicHash::Algorithm> FwupdBackend::gchecksumToQChr
 
 FwupdBackend::~FwupdBackend()
 {
+    g_cancellable_cancel(m_cancellable);
+    m_threadPool.waitForDone(200);
+    m_threadPool.clear();
+    g_object_unref(m_cancellable);
+
     g_object_unref(client);
 }
 
@@ -114,10 +120,9 @@ void FwupdBackend::addUpdates()
     if (!devices)
     {
         if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO))
-        {
             qDebug() << "Fwupd Info: No Devices Found";
-            handleError(&error);
-        }
+        else
+            handleError(error);
         return;
     }
 
@@ -160,7 +165,7 @@ void FwupdBackend::addUpdates()
         } else {
             if (!g_error_matches(error2, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO))
             {
-                handleError(&error2);
+                handleError(error2);
             }
         }
     }
@@ -261,7 +266,7 @@ bool FwupdBackend::downloadFile(const QUrl &uri, const QString &filename)
     return true;
 }
 
-void FwupdBackend::refreshRemote(FwupdBackend* backend, FwupdRemote* remote, quint64 cacheAge)
+void FwupdBackend::refreshRemote(FwupdBackend* backend, FwupdRemote* remote, quint64 cacheAge, GCancellable *cancellable)
 {
     if (!fwupd_remote_get_filename_cache_sig(remote))
     {
@@ -333,22 +338,24 @@ void FwupdBackend::refreshRemote(FwupdBackend* backend, FwupdRemote* remote, qui
     }
 
     g_autoptr(GError) error = nullptr;
-    if (!fwupd_client_update_metadata(backend->client, fwupd_remote_get_id(remote), filename.toUtf8().constData(), filenameSig.toUtf8().constData(), nullptr, &error))
+    if (!fwupd_client_update_metadata(backend->client, fwupd_remote_get_id(remote), filename.toUtf8().constData(), filenameSig.toUtf8().constData(), cancellable, &error))
     {
-        backend->handleError(&error);
+        backend->handleError(error);
     }
 }
 
-void FwupdBackend::handleError(GError **perror)
+void FwupdBackend::handleError(GError *perror)
 {
     //TODO: localise the error message
-    if ((*perror)->code != FWUPD_ERROR_NOTHING_TO_DO) {
-        const QString msg = QString::fromUtf8((*perror)->message);
+    if (!g_error_matches(perror, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE) && !g_error_matches(perror, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO)) {
+        const QString msg = QString::fromUtf8(perror->message);
         QTimer::singleShot(0, this, [this, msg](){
             Q_EMIT passiveMessage(msg);
         });
+        qWarning() << "Fwupd Error" << perror->code << perror->message;
     }
-    qWarning() << "Fwupd Error" << (*perror)->code << (*perror)->message;
+//     else
+//         qDebug() << "Fwupd skipped" << perror->code << perror->message;
 }
 
 QString FwupdBackend::cacheFile(const QString &kind, const QString &basename)
@@ -371,16 +378,16 @@ void FwupdBackend::checkForUpdates()
         return;
 
     auto fw = new QFutureWatcher<GPtrArray*>(this);
-    fw->setFuture(QtConcurrent::run([this] () -> GPtrArray*
+    fw->setFuture(QtConcurrent::run(&m_threadPool, [this] () -> GPtrArray*
         {
             const uint cacheAge = (24*60*60); // Check for updates every day
             g_autoptr(GError) error = nullptr;
 
             /* get devices */
-            GPtrArray* devices = fwupd_client_get_devices(client, nullptr, nullptr);
+            GPtrArray* devices = fwupd_client_get_devices(client, m_cancellable, nullptr);
 
 
-            g_autoptr(GPtrArray) remotes = fwupd_client_get_remotes(client, nullptr, &error);
+            g_autoptr(GPtrArray) remotes = fwupd_client_get_remotes(client, m_cancellable, &error);
             for(uint i = 0; remotes && i < remotes->len; i++)
             {
                 FwupdRemote *remote = (FwupdRemote *)g_ptr_array_index(remotes, i);
@@ -390,7 +397,7 @@ void FwupdBackend::checkForUpdates()
                 if (fwupd_remote_get_kind(remote) == FWUPD_REMOTE_KIND_LOCAL)
                     continue;
 
-                refreshRemote(this, remote, cacheAge);
+                refreshRemote(this, remote, cacheAge, m_cancellable);
             }
             return devices;
         }
@@ -402,9 +409,17 @@ void FwupdBackend::checkForUpdates()
         auto devices = fw->result();
         for(uint i = 0; devices && i < devices->len; i++) {
             FwupdDevice *device = (FwupdDevice *) g_ptr_array_index(devices, i);
+            g_autoptr(GError) error = nullptr;
+            g_autoptr(GPtrArray) releases = fwupd_client_get_releases(client, fwupd_device_get_id(device), nullptr, &error);
+
+            if (error) {
+                if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE) || g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED))
+                    continue;
+
+                handleError(error);
+            }
 
             auto res = createDevice(device);
-            g_autoptr(GPtrArray) releases = fwupd_client_get_releases(client, fwupd_device_get_id(device), nullptr, nullptr);
             for (uint i=0; releases && i<releases->len; ++i) {
                 FwupdRelease *release = (FwupdRelease *)g_ptr_array_index(releases, i);
                 if (res->installedVersion().toUtf8() == fwupd_release_get_version(release)) {
@@ -528,7 +543,7 @@ AbstractResource * FwupdBackend::resourceForFile(const QUrl& path)
         }
         else
         {
-            handleError(&error);
+            handleError(error);
         }
     }
     return app;
