@@ -30,26 +30,16 @@
 FwupdResource::FwupdResource(QString name, AbstractResourcesBackend* parent)
     : AbstractResource(parent)
     , m_name(std::move(name))
-    , m_state(State::Broken)
 {
+    Q_ASSERT(!m_name.isEmpty());
     setObjectName(m_name);
 }
 
-QList<PackageState> FwupdResource::addonsInformation()
-{
-    return m_addons;
-}
-
 QString FwupdResource::availableVersion() const
 {
     return m_version;
 }
 
-QStringList FwupdResource::allResourceNames() const
-{
-    return { m_name };
-}
-
 QStringList FwupdResource::categories()
 {
    return m_categories;
@@ -87,7 +77,7 @@ QUrl FwupdResource::donationURL()
 
 QVariant FwupdResource::icon() const
 {
-    return  m_iconName;
+    return m_iconName;
 }
 
 QString FwupdResource::installedVersion() const
@@ -107,7 +97,7 @@ QString FwupdResource::longDescription()
 
 QString FwupdResource::name() const
 {
-    return m_name;
+    return m_displayName.isEmpty() ? m_name : m_displayName;
 }
 
 QString FwupdResource::vendor() const
@@ -153,30 +143,6 @@ void FwupdResource::setState(AbstractResource::State state)
 
 }
 
-void FwupdResource::setAddons(const AddonList& addons)
-{
-    Q_FOREACH(const QString& toInstall, addons.addonsToInstall())
-    {
-        setAddonInstalled(toInstall, true);
-    }
-    Q_FOREACH(const QString& toRemove, addons.addonsToRemove())
-    {
-        setAddonInstalled(toRemove, false);
-    }
-}
-
-void FwupdResource::setAddonInstalled(const QString& addon, bool installed)
-{
-    for(auto & elem : m_addons)
-    {
-        if(elem.name() == addon)
-        {
-            elem.setInstalled(installed);
-        }
-    }
-}
-
-
 void FwupdResource::invokeApplication() const
 {
     qWarning() << "Not Launchable";
@@ -189,5 +155,47 @@ QUrl FwupdResource::url() const
 
 QString FwupdResource::executeLabel() const
 {
-    return i18n("Not Invokable");
+    return QStringLiteral("Not Invokable");
+}
+
+void FwupdResource::setReleaseDetails(FwupdRelease* release)
+{
+    m_origin = QString::fromUtf8(fwupd_release_get_remote_id(release));
+    m_summary = QString::fromUtf8(fwupd_release_get_summary(release));
+    m_vendor = QString::fromUtf8(fwupd_release_get_vendor(release));
+    m_size = fwupd_release_get_size(release);
+    m_version = QString::fromUtf8(fwupd_release_get_version(release));
+    m_description = QString::fromUtf8((fwupd_release_get_description(release)));
+    m_homepage = QUrl(QString::fromUtf8(fwupd_release_get_homepage(release)));
+    m_license = QString::fromUtf8(fwupd_release_get_license(release));
+    m_updateURI = QString::fromUtf8(fwupd_release_get_uri(release));
+}
+
+void FwupdResource::setDeviceDetails(FwupdDevice* dev)
+{
+    m_isLiveUpdatable = fwupd_device_has_flag(dev, FWUPD_DEVICE_FLAG_UPDATABLE);
+    m_isOnlyOffline = fwupd_device_has_flag(dev, FWUPD_DEVICE_FLAG_ONLY_OFFLINE);
+    m_needsReboot = fwupd_device_has_flag(dev, FWUPD_DEVICE_FLAG_NEEDS_REBOOT);
+    m_isDeviceRemoval = !fwupd_device_has_flag(dev, FWUPD_DEVICE_FLAG_INTERNAL);
+    m_needsBootLoader = fwupd_device_has_flag(dev, FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER);
+
+    if (fwupd_device_get_name(dev))
+    {
+        QString vendorDesc = QString::fromUtf8(fwupd_device_get_name(dev));
+        const QString vendorName = QString::fromUtf8(fwupd_device_get_vendor(dev));
+
+        if (!vendorDesc.startsWith(vendorName))
+            vendorDesc = vendorName + QLatin1Char(' ') + vendorDesc;
+        m_displayName = vendorDesc;
+     }
+    m_summary = QString::fromUtf8(fwupd_device_get_summary(dev));
+    m_vendor = QString::fromUtf8(fwupd_device_get_vendor(dev));
+    m_releaseDate = QDateTime::fromSecsSinceEpoch(fwupd_device_get_created(dev)).date();
+    m_version = QString::fromUtf8(fwupd_device_get_version(dev));
+    m_description = QString::fromUtf8((fwupd_device_get_description(dev)));
+
+    if (fwupd_device_get_icons(dev)->len >= 1)
+        m_iconName = QString::fromUtf8((const gchar *)g_ptr_array_index(fwupd_device_get_icons(dev), 0));// Check wether given icon exists or not!
+    else
+        m_iconName = QString::fromUtf8("device-notifier");
 }
